@@ -9,7 +9,7 @@ class ResourceType(Enum):
     Dashboard = auto()
     User = auto()
     Column = auto()
-    TypeMetadata = auto()
+    Type_Metadata = auto()
     Feature = auto()
 
 
