@@ -17,6 +17,8 @@ class LineageItem:
     badges: Optional[List[Badge]] = None
     usage: Optional[int] = None  # statistic to sort lineage items by
     parent: Optional[str] = None  # key of the parent entity, used to create the relationships in graph
+    link: Optional[str] = None  # internal link to redirect to different than the resource details page
+    in_amundsen: Optional[bool] = None  # it is possible to have lineage that doesn't exist in Amundsen in that moment
 
 
 class LineageItemSchema(AttrsSchema):
